from typing import *


class Chebyshev:
    @classmethod
    def basis(cls, /, deg: int):
        """
        usage.sample-usage: 1
        """
        ...
